import { Characters } from './characters';
/**
 * Class for encoding characters to an SVG document.
 */
export declare class SvgEncoder extends Object {
    /**
     * Characters instance.
     */
    readonly characters: Characters;
    /**
     * Optionall header for the SVG code.
     */
    header: string;
    /**
     * SVG document attributes, null and undefined skipped, others string cast.
     */
    svgAttrs: {
        [attr: string]: unknown;
    };
    /**
     * SVG document attributes, null and undefined skipped, others string cast.
     */
    pathAttrs: {
        [attr: string]: unknown;
    };
    /**
     * Code to prepend to SVG document.
     */
    prepend: string;
    /**
     * Code to append to SVG document.
     */
    append: string;
    /**
     * SvgEncoder constructor.
     *
     * @param characters Characters instance.
     */
    constructor(characters: Characters);
    /**
     * Encode XML entities.
     *
     * @param str String to encode.
     * @returns Encoded string.
     */
    entities(str: string): string;
    /**
     * Create an XML tag.
     *
     * @param name Tag name.
     * @param attrs Tag arributes.
     * @param content String content, or null for self-closing.
     * @returns XML tag.
     */
    tag(name: string, attrs?: Readonly<{
        [attr: string]: unknown;
    }>, content?: string | null): string;
    /**
     * Generate SVG circle tag.
     *
     * @param cx Center X.
     * @param cy Center Y.
     * @param r Radius size.
     * @returns Circle tag.
     */
    circle(cx: number, cy: number, r: number): string;
    /**
     * Generate SVG line tag.
     *
     * @param x1 Start X.
     * @param y1 Start Y.
     * @param x2 End X.
     * @param y2 End Y.
     * @returns Line tag.
     */
    line(x1: number, y1: number, x2: number, y2: number): string;
    /**
     * Generate SVG path tag.
     *
     * @param path Sequence of alternating X and Y positions.
     * @returns Path tag.
     */
    path(path: readonly number[]): string;
    /**
     * Convert element data to SVG tag, based on data length.
     *
     * @param element Element data.
     * @returns SVG tag.
     */
    element(element: readonly number[]): string;
    /**
     * Encode a character as SVG code.
     *
     * @param character The character to encode.
     * @returns SVG code or null if character is unknown.
     */
    encode(character: string): string | null;
}
